.. craft providers documentation root file

Craft Providers
===========================================

Craft Providers is a Python package for managing software builds in containers
on behalf of tools using the Craft Parts framework.

Craft Providers aims to provide Python interfaces for instantiating build
environments, configuring base images and executing builds for a variety of
target environments.

The aim of this package is to provide a uniform, extensible set of interfaces
that other tools and packages can use to build software without needing to
know the particular details of each build environment or system.

This package is most useful for implementers of tools using the Craft Parts
framework that need to provide support for additional build environments.

.. toctree::
   :maxdepth: 1
   :hidden:

   tutorials/index
   howto/index
   reference/index
   explanation/index
   changelog

.. grid:: 1 1 2 2

   .. grid-item-card:: :ref:`Tutorial <tutorial>`

      **Get started** with a hands-on introduction to Craft Providers

   .. grid-item-card:: :ref:`How-to guides <howto>`

      **Step-by-step guides** covering key operations and common tasks

.. grid:: 1 1 2 2
   :reverse:

   .. grid-item-card:: :ref:`Reference <reference>`

      **Technical information** about Craft Providers

   .. grid-item-card:: :ref:`Explanation <explanation>`

      **Discussion and clarification** of key topics

Project and community
=====================

Craft Providers is a member of the Canonical family. It's an open source project
that warmly welcomes community projects, contributions, suggestions, fixes
and constructive feedback.

* `Ubuntu Code of Conduct <https://ubuntu.com/community/code-of-conduct>`_.
* `Canonical contributor licenses agreement
  <https://ubuntu.com/legal/contributors>`_.

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
